django\_storage.tests package
=============================

Submodules
----------

django\_storage.tests.data module
---------------------------------

.. automodule:: django_storage.tests.data
   :members:
   :undoc-members:
   :show-inheritance:

django\_storage.tests.test\_aws\_s3\_storage module
---------------------------------------------------

.. automodule:: django_storage.tests.test_aws_s3_storage
   :members:
   :undoc-members:
   :show-inheritance:

django\_storage.tests.test\_filesystem\_storage module
------------------------------------------------------

.. automodule:: django_storage.tests.test_filesystem_storage
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: django_storage.tests
   :members:
   :undoc-members:
   :show-inheritance:
